@@ -7,6 +7,7 @@ from django.utils.translation import gettext_lazy as _
 
 from isc_common.auth.models.abstract_base_user import AbstractBaseUser
 from isc_common.auth.models.usergroup import UserGroup
+from isc_common.common import unknown
 from isc_common.fields.code_field import CodeStrictField
 from isc_common.fields.name_field import NameField
 from isc_common.models.audit import AuditModel
@@ -78,10 +79,11 @@ class AbstractUser(AbstractBaseUser, AuditModel):
 
     @classmethod
     def short_name(cls, first_name, middle_name, last_name, translit=False):
+        from isc_common.models.audit import AuditModel
+
         if first_name is None and middle_name is None and last_name is None:
             raise Exception('first_name is None and middle_name is None and last_name is None')
 
-        from isc_common.models.audit import AuditModel
         fn = f'{first_name.strip()[0:1].upper() if first_name else ""}'
         if fn != '':
             fn = ' ' + fn + '.'
@@ -94,12 +96,16 @@ class AbstractUser(AbstractBaseUser, AuditModel):
             res = f'{last_name.strip()} {fn}{mn}'
         else:
             res = f'{fn}{mn}'
+
         if translit is True:
             return AuditModel.translit(res.strip())
+
         return res.strip()
 
     @property
     def get_short_name(self):
+        username = self.username if self.username != unknown else ''
+
         fn = f'{self.first_name.strip()[0:1].upper() if self.first_name else ""}'
         if fn != '':
             fn = ' ' + fn + '.'
@@ -108,9 +114,9 @@ class AbstractUser(AbstractBaseUser, AuditModel):
         if mn != '':
             mn = ' ' + mn + '.'
 
-        res = f'{self.last_name.strip() if self.last_name else self.username}{fn}{mn}'
+        res = f'{self.last_name.strip() if self.last_name else username}{fn}{mn}'
         if res.strip() == "":
-            res = self.username
+            res = username
         return res.strip()
 
     @property
@@ -118,7 +124,10 @@ class AbstractUser(AbstractBaseUser, AuditModel):
         res = f'{self.first_name.strip()[0:1].upper() if self.first_name else ""} ' \
               f'{self.middle_name.strip()[0:1].upper() if self.middle_name else ""}'
         if res.strip() == "":
-            res = self.username
+            if self.username != unknown:
+                res = self.username
+            else:
+                res = ''
         return res.strip()
 
     def user_short_name(self):
