@@ -12,14 +12,7 @@ logger = logging.getLogger(__name__)
 
 
 class User_e_mailsQuerySet(Model_e_mailQuerySet):
-    def delete(self):
-        return super().delete()
-
-    def create(self, **kwargs):
-        return super().create(**kwargs)
-
-    def filter(self, *args, **kwargs):
-        return super().filter(*args, **kwargs)
+    pass
 
 
 class User_e_mailsManager(AuditManager):
@@ -29,8 +22,8 @@ class User_e_mailsManager(AuditManager):
             ('main', 'Главная'),  # 1
         ), default=0, db_index=True)
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record ) :
         res = {
             'id': record.id,
             'editing': record.editing,
