@@ -11,7 +11,8 @@ def UserGroup_Fetch(request):
         DSResponse(
             request=request,
             data=UserGroup.objects.
-                exclude(code=developers).
+                # exclude(code=developers).
+                exclude().
                 get_range_rows1(
                 request=request,
                 function=GroupManager.getRecord
