@@ -95,121 +95,20 @@ class Body:
             else:
                 raise Exception('user not enable type')
 
+
 def JsonWSResponseWithException(printing=False, printing_res=False):
-    try:
-        class JE:
-            def __init__(self, func):
-                self.func = func
-                self.pp = pprint.PrettyPrinter(indent=4)
+    def JsonWSResponseWithExceptionInner(func):
+        def print_in(o, str=None):
+            pp = pprint.PrettyPrinter(indent=4)
 
-            def print(self, o, str=None):
-                if str:
-                    print(f"=========== Begin {str} ========================")
-                else:
-                    print(f"=========== Begin {o.__class__.__name__} ========================")
-                if isinstance(o, dict):
-                    self.pp.pprint(RequestData(o).getDataWithOutField(['pp', '_state']).dict())
-                elif isinstance(o, object):
-                    self.pp.pprint(RequestData(o.__dict__).getDataWithOutField(['pp', '_state']).dict())
-
-                if str:
-                    print(f"=========== End   {str} ========================")
-                else:
-                    print(f"=========== End   {o.__class__.__name__} ========================")
-                print("\n")
-
-            def __call__(self, *args, **kwargs):
-                from isc_common.json import BytesToJson
-                request = args[0]
-
-                self.port = request.GET.get('ws_port')
-                if self.port is None:
-                    self.port = request.GET.get('port')
-                    if self.port is None:
-                        self.port = settings.WS_PORT
-                        if self.port is None:
-                            raise Exception_WS_Enabled(Common.arraund_error('Do not have ws_port'))
-
-                self.host = request.GET.get('ws_host')
-                if self.host is None:
-                    self.host = request.GET.get('host')
-                    if self.host is None:
-                        self.host = settings.WS_HOST
-                        if self.host is None:
-                            raise Exception_WS_Enabled(Common.arraund_error('Do not have ws_host'))
-
-                self.channel = request.GET.get('ws_channel')
-                if self.channel is None:
-                    body = BytesToJson(request.body)
-                    body = Body(body, request.session)
-                    if settings.WS_CHANNEL is not None:
-                        self.channel = f'''{settings.WS_CHANNEL}_{body.login}'''
-
-                try:
-                    if printing:
-                        _request = DSRequest(request)
-                        self.print(_request)
-                        self.print(request.COOKIES, 'request.COOKIES')
-                        self.print(request.GET, 'request.GET')
-                        self.print(request.POST, 'request.POST')
-                        self.print(request.META, 'request.META')
-
-                    res = self.func(*args, **kwargs)
-                    if printing_res:
-                        self.print(res)
-
-                    return res
-                except Exception as ex:
-                    exc_info = sys.exc_info()
-                    stackTrace = traceback.format_exception(*exc_info)
-                    message = str(ex)
-
-                    try:
-                        ws = create_connection(f"ws://{self.host}:{self.port}/ws/{self.channel}/")
-                        ws.send(json.dumps(dict(message=message, stackTrace=stackTrace, type="error")))
-                        ws.close()
-                    except Exception as ex:
-
-                        exc_info = sys.exc_info()
-                        message = str(ex)
-                        stackTrace = traceback.format_exception(*exc_info)
-
-                        logging.error(message)
-
-                        for x in stackTrace:
-                            logger.error(x)
-
-                        del exc_info
-
-                    for x in stackTrace:
-                        logger.error(x)
-
-                    return JsonResponse(DSResponseOk().response)
-
-        return JE
-    except Exception_WS_Enabled:
-        return JsonResponseWithExceptionOld(printing=printing, printing_res=printing_res)
-
-
-def JsonResponseWithException(printing=False, printing_res=False):
-    return JsonWSResponseWithException(printing=printing, printing_res=printing_res)
-
-
-def JsonResponseWithExceptionOld(printing=False, printing_res=False):
-    class JE:
-        def __init__(self, func):
-            self.func = func
-            self.pp = pprint.PrettyPrinter(indent=4)
-
-        def print(self, o, str=None):
             if str:
                 print(f"=========== Begin {str} ========================")
             else:
                 print(f"=========== Begin {o.__class__.__name__} ========================")
             if isinstance(o, dict):
-                self.pp.pprint(RequestData(o).getDataWithOutField(['pp', '_state']).dict())
+                pp.pprint(RequestData(o).getDataWithOutField(['pp', '_state']).dict())
             elif isinstance(o, object):
-                self.pp.pprint(RequestData(o.__dict__).getDataWithOutField(['pp', '_state']).dict())
+                pp.pprint(RequestData(o.__dict__).getDataWithOutField(['pp', '_state']).dict())
 
             if str:
                 print(f"=========== End   {str} ========================")
@@ -217,94 +116,45 @@ def JsonResponseWithExceptionOld(printing=False, printing_res=False):
                 print(f"=========== End   {o.__class__.__name__} ========================")
             print("\n")
 
-        def __call__(self, *args, **kwargs):
-            try:
-                if printing:
-                    request = args[0]
-                    _request = DSRequest(request)
-                    self.print(_request)
-                    self.print(request.COOKIES, 'request.COOKIES')
-                    self.print(request.GET, 'request.GET')
-                    self.print(request.POST, 'request.POST')
-                    self.print(request.META, 'request.META')
-
-                res = self.func(*args, **kwargs)
-                if printing_res:
-                    self.print(res)
-                return res
-            except Exception as ex:
-                exc_info = sys.exc_info()
-                stackTrace = traceback.format_exception(*exc_info)
-                message = str(ex)
-                for x in stackTrace:
-                    logger.error(x)
-
-                del exc_info
-
-                return JsonResponse(DSResponseFailure(message=message, stackTrace=stackTrace).response)
-
-    return JE
-
-
-def JsonWSPostResponseWithException(printing=False, printing_res=False):
-    class JE:
-        def __init__(self, func):
-            self.func = func
-            self.pp = pprint.PrettyPrinter(indent=4)
-
-        def print(self, o, str=None):
-            if str:
-                print(f"=========== Begin {str} ========================")
-            else:
-                print(f"=========== Begin {o.__class__.__name__} ========================")
-            if isinstance(o, dict):
-                self.pp.pprint(RequestData(o).getDataWithOutField(['pp', '_state']).dict())
-            elif isinstance(o, object):
-                self.pp.pprint(RequestData(o.__dict__).getDataWithOutField(['pp', '_state']).dict())
-
-            if str:
-                print(f"=========== End   {str} ========================")
-            else:
-                print(f"=========== End   {o.__class__.__name__} ========================")
-            print("\n")
-
-        def __call__(self, *args, **kwargs):
+        def wrapper(*args, **kwargs):
             from isc_common.json import BytesToJson
             request = args[0]
 
-            self.port = request.POST.get('ws_port')
-            if self.port is None:
-                self.port = settings.WS_PORT
-                if not self.port:
-                    raise Exception(Common.arraund_error('Do not have ws_port'))
+            port = request.GET.get('ws_port')
+            if port is None:
+                port = request.GET.get('port')
+                if port is None:
+                    port = settings.WS_PORT
+                    if port is None:
+                        raise Exception_WS_Enabled(Common.arraund_error('Do not have ws_port'))
 
-            self.host = request.POST.get('ws_host')
-            if self.host is None:
-                self.host = settings.WS_HOST
-                if not self.host:
-                    raise Exception(Common.arraund_error('Do not have ws_host'))
+            host = request.GET.get('ws_host')
+            if host is None:
+                host = request.GET.get('host')
+                if host is None:
+                    host = settings.WS_HOST
+                    if host is None:
+                        raise Exception_WS_Enabled(Common.arraund_error('Do not have ws_host'))
 
-            self.channel = request.POST.get('ws_channel')
-            if self.channel is None:
+            channel = request.GET.get('ws_channel')
+            if channel is None:
                 body = BytesToJson(request.body)
                 body = Body(body, request.session)
                 if settings.WS_CHANNEL is not None:
-                    self.channel = f'''{settings.WS_CHANNEL}_{body.login}'''
-                    if self.channel is None:
-                        raise Exception(Common.arraund_error('Do not have ws_channel'))
+                    channel = f'''{settings.WS_CHANNEL}_{body.login}'''
 
             try:
                 if printing:
                     _request = DSRequest(request)
-                    self.print(_request)
-                    self.print(request.COOKIES, 'request.COOKIES')
-                    self.print(request.GET, 'request.GET')
-                    self.print(request.POST, 'request.POST')
-                    self.print(request.META, 'request.META')
+                    print_in(_request)
+                    print_in(request.COOKIES, 'request.COOKIES')
+                    print_in(request.GET, 'request.GET')
+                    print_in(request.POST, 'request.POST')
+                    print_in(request.META, 'request.META')
 
-                res = self.func(*args, **kwargs)
+                res = func(*args, **kwargs)
                 if printing_res:
-                    self.print(res)
+                    print_in(res)
 
                 return res
             except Exception as ex:
@@ -313,7 +163,7 @@ def JsonWSPostResponseWithException(printing=False, printing_res=False):
                 message = str(ex)
 
                 try:
-                    ws = create_connection(f"ws://{self.host}:{self.port}/ws/{self.channel}/")
+                    ws = create_connection(f"ws://{host}:{port}/ws/{channel}/")
                     ws.send(json.dumps(dict(message=message, stackTrace=stackTrace, type="error")))
                     ws.close()
                 except Exception as ex:
@@ -334,7 +184,20 @@ def JsonWSPostResponseWithException(printing=False, printing_res=False):
 
                 return JsonResponse(DSResponseOk().response)
 
-    return JE
+        return wrapper
+    return JsonWSResponseWithExceptionInner
+
+
+def JsonResponseWithException(printing=False, printing_res=False):
+    return JsonWSResponseWithException(printing=printing, printing_res=printing_res)
+
+
+def JsonResponseWithExceptionOld(printing=False, printing_res=False):
+    return JsonWSResponseWithException(printing=printing, printing_res=printing_res)
+
+
+def JsonWSPostResponseWithException(printing=False, printing_res=False):
+    return JsonWSResponseWithException(printing=printing, printing_res=printing_res)
 
 
 class DSResponse(RPCResponse):
