@@ -15,8 +15,8 @@ class Deleted_progressesQuerySet(AuditQuerySet):
 
 class Deleted_progressesManager(AuditManager):
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         res = {
             'id': record.id,
             'editing': record.editing,
