@@ -1,5 +1,7 @@
 import logging
 
+from bitfield import BitField
+from django.db import connection
 from django.db.models import TextField
 
 from isc_common.models.audit import AuditModel, AuditManager, AuditQuerySet
@@ -8,14 +10,6 @@ logger = logging.getLogger(__name__)
 
 
 class Model_text_informationsQuerySet(AuditQuerySet):
-    def delete(self):
-        return super().delete()
-
-    def create(self, **kwargs):
-        return super().create(**kwargs)
-
-    def filter(self, *args, **kwargs):
-        return super().filter(*args, **kwargs)
 
     def update_or_create(self, defaults=None, **kwargs):
         text = defaults.get('text')
@@ -34,25 +28,41 @@ class Model_text_informationsQuerySet(AuditQuerySet):
             defaults = dict(text=text_item)
             return super().update_or_create(defaults=defaults, **kwargs)
 
+
 class Text_informationsQuerySet(AuditQuerySet):
-    def delete(self):
-        return super().delete()
-
-    def create(self, **kwargs):
-        return super().create(**kwargs)
-
-    def filter(self, *args, **kwargs):
-        return super().filter(*args, **kwargs)
+    pass
 
 
 class Text_informationsManager(AuditManager):
+    @classmethod
+    def props(cls):
+        return BitField(flags=(
+            ('checked_src_icluded', 'Выполнена проверка на содержащие картинки'),  # 1
+        ), default=0, db_index=True)
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def get_text( cls , model_id , model_code , model , model_text , model_text_fk ) :
+        with connection.cursor() as cursor :
+            cursor.execute( f'''select cml.id, cml.text
+                                from {model} as lg
+                                join {model_text} as lgl on lg.id = lgl.{model_text_fk}
+                                join isc_common_text_informations as cml on lgl.text_id = cml.id
+                                where lg.id = %s
+                                and lgl.code = %s''' , [ model_id , model_code ] )
+            row = cursor.fetchone()
+            if row is None :
+                return None , None
+            else :
+                id , text = row
+            return id , text
+
+    @classmethod
+    def getRecord(cls, record ) :
         res = {
             'id': record.id,
             'editing': record.editing,
             'deliting': record.deliting,
+            'text': record.text,
         }
         return res
 
@@ -61,6 +71,7 @@ class Text_informationsManager(AuditManager):
 
 
 class Text_informations(AuditModel):
+    props = Text_informationsManager.props()
     text = TextField(db_index=True)
 
     objects = Text_informationsManager()
